@@ -19,7 +19,7 @@ use Tags::HTML::Element::Textarea;
 Readonly::Array our @TEXT_KEYS => qw(add_comment author date save);
 Readonly::Scalar our $CSS_CLASS_ADD_COMMENT => 'add-comment';
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -188,6 +188,11 @@ sub _process_css {
 	my $self = shift;
 
 	$self->{'css'}->put(
+		['s', '.'.$self->{'css_class'}],
+		['d', 'font-family', 'Arial, Helvetica, sans-serif'],
+		['d', 'margin', '1em'],
+		['e'],
+
 		['s', '.'.$self->{'css_class'}.' .main-message'],
 		['d', 'border', '1px solid #ccc'],
 		['d', 'padding', '20px'],
@@ -698,6 +703,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
